/* eslint-disable no-console */
import { ErrorData } from '@/utils/error-report/ErrorData';
import { SerializedError } from '@reduxjs/toolkit';
// eslint-disable-next-line import/no-cycle
import { store } from '@/redux/store';

export const createErrorData = (error: Error | SerializedError | undefined): ErrorData => {
  let stacktrace = '';
  if (error !== undefined) {
    stacktrace = error.stack !== undefined ? error.stack : '';
  }

  let { login } = store.getState().user;
  if (!login) {
    login = 'anonymous';
  }

  const errorData: ErrorData = {
    url: window.location.href,
    login,
    browser: null, // TODO
    comment: null,
    email: null, // TODO
    javaStacktrace: null, // TODO
    stacktrace,
    timestamp: null, // TODO
    version: null, // TODO
  };
  return errorData;
};

export const handleError = (error: Error | SerializedError | undefined): void => {
  const errorData = createErrorData(error);
  // eslint-disable-next-line no-console
  console.log(errorData);
};

export const initializeErrorReporting = (): void => {
  if (typeof window !== 'undefined') {
    window.onerror = (msg, url, lineNo, columnNo, error): boolean => {
      handleError(error);
      return true;
    };
  }
};
